summaryrefslogtreecommitdiff
path: root/cryptlib.h
diff options
context:
space:
mode:
authorJeffrey Walton <noloader@gmail.com>2019-01-28 09:06:49 -0500
committerJeffrey Walton <noloader@gmail.com>2019-01-28 09:06:49 -0500
commit30e7469f5ef4a529a3e50d391af3904f89e76953 (patch)
treed878e38e0c7c673a2d013cce656949a476911dcf /cryptlib.h
parent315e54e63d5880ade8f2bbeb26c5f536b63faf05 (diff)
downloadcryptopp-git-30e7469f5ef4a529a3e50d391af3904f89e76953.tar.gz
Clear Doxygen warnings
Diffstat (limited to 'cryptlib.h')
-rw-r--r--cryptlib.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/cryptlib.h b/cryptlib.h
index 76012686..bbd1d87e 100644
--- a/cryptlib.h
+++ b/cryptlib.h
@@ -1331,7 +1331,7 @@ public:
/// \brief Encrypts and calculates a MAC in one call
/// \param ciphertext the encryption buffer
/// \param mac the mac buffer
/// \param macLength the size of the MAC buffer, in bytes
/// \param iv the iv buffer
/// \param ivLength the size of the IV buffer, in bytes
/// \param header the AAD buffer
@@ -1345,19 +1345,19 @@ public:
/// \brief Decrypts and verifies a MAC in one call
/// \param message the decryption buffer
/// \param mac the mac buffer
/// \param macLength the size of the MAC buffer, in bytes
/// \param iv the iv buffer
/// \param ivLength the size of the IV buffer, in bytes
/// \param header the AAD buffer
/// \param headerLength the size of the AAD buffer, in bytes
- /// \param cipher the cipher buffer
- /// \param cipherLength the size of the ciphertext buffer, in bytes
+ /// \param ciphertext the ciphertext buffer
+ /// \param ciphertextLength the size of the ciphertext buffer, in bytes
/// \return true if the MAC is valid and the decoding succeeded, false otherwise
/// \details DecryptAndVerify() decrypts and verifies the MAC in one call.
/// <tt>message</tt> is a decryption buffer and should be at least as large as the ciphertext buffer.
/// \details The function returns true iff MAC is valid. DecryptAndVerify() assumes the MAC
/// is truncated if <tt>macLength < TagSize()</tt>.
- virtual bool DecryptAndVerify(byte *message, const byte *mac, size_t macLength, const byte *iv, int ivLength, const byte *header, size_t headerLength, const byte *ciphertext, size_t ciphertextLength);
+ virtual bool DecryptAndVerify(byte *message, const byte *mac, size_t macSize, const byte *iv, int ivLength, const byte *header, size_t headerLength, const byte *ciphertext, size_t ciphertextLength);
/// \brief Provides the name of this algorithm
/// \return the standard algorithm name
@@ -1331,7 +1331,7 @@ public:
/// \param ciphertext the encryption buffer
/// \param mac the mac buffer
- /// \param macLength the size of the MAC buffer, in bytes
+ /// \param macSize the size of the MAC buffer, in bytes
/// \param iv the iv buffer
/// \param ivLength the size of the IV buffer, in bytes
@@ -1345,19 +1345,19 @@ public:
/// \param message the decryption buffer
/// \param mac the mac buffer
- /// \param macLength the size of the MAC buffer, in bytes
+ /// \param macSize the size of the MAC buffer, in bytes
/// \param iv the iv buffer
/// \param ivLength the size of the IV buffer, in bytes